package com.chelvc.cloud.vehicle.api.util;

import com.chelvc.framework.common.util.DateUtils;
import lombok.extern.slf4j.Slf4j;

import java.util.Date;

/**
 * 优惠活动通用验证类
 *
 * @author qizai
 * @date 2023/10/16
 */
@Slf4j
public class PromotionUtils {

    public static final String START_TIME_COLUMN = "start_time";
    public static final String END_TIME_COLUMN = "end_time";
    public static final Long PLATFORM_ID = 0L;
    public static final String PLATFORM_NAME = "platform";

    /**
     * 参数验证
     * 1、活动起始时间必须大于当前时间
     * 2、验证活动开始时间是否大于活动结束时间
     *
     * @param startTime 活动开始时间
     * @param endTime   活动结束时间
     */
    public static void checkPromotionTime(Date startTime, Date endTime) {
        if (startTime == null) {
            throw new RuntimeException("活动起始时间不能为空");
        }

        Date now = DateUtils.today();

        //如果活动起始时间小于现在时间
        if (now.after(startTime)) {
            throw new RuntimeException("活动起始时间不能小于当前时间");
        }
        //如果活动结束时间小于现在时间
        if (endTime != null && now.after(endTime)) {
            throw new RuntimeException("活动结束时间不能小于当前时间");
        }
        //开始时间不能大于结束时间
        if (endTime != null && startTime.after(endTime)) {
            throw new RuntimeException("活动起始时间必须大于结束时间");
        }
    }
}
